@@ -4,12 +4,13 @@ package Mail::AuthenticationResults::Header::Entry;
 require 5.010;
 use strict;
 use warnings;
-our $VERSION = '1.20180113'; # VERSION
+our $VERSION = '1.20180211'; # VERSION
 use Scalar::Util qw{ refaddr };
 use Carp;
 
 use base 'Mail::AuthenticationResults::Header::Base';
 
+
 sub _HAS_KEY{ return 1; }
 sub _HAS_VALUE{ return 1; }
 sub _HAS_CHILDREN{ return 1; }
@@ -36,7 +37,15 @@ Mail::AuthenticationResults::Header::Entry - Class modelling Main Entry parts of
 
 =head1 VERSION
 
-version 1.20180113
+version 1.20180211
+
+=head1 DESCRIPTION
+
+Entries are the main result of an Authentication Resutls check, an example of this
+would be "dkim=pass" or "dmarc=fail", there may be additional comments of sub entries
+associated with this entry, these are represented as children of this class.
+
+Please see L<Mail::AuthenticationResults::Header::Base>
 
 =head1 AUTHOR
 
