@@ -4,11 +4,12 @@ package Mail::AuthenticationResults::Header::SubEntry;
 require 5.010;
 use strict;
 use warnings;
-our $VERSION = '1.20180113'; # VERSION
+our $VERSION = '1.20180211'; # VERSION
 use Carp;
 
 use base 'Mail::AuthenticationResults::Header::Base';
 
+
 sub _HAS_KEY{ return 1; }
 sub _HAS_VALUE{ return 1; }
 sub _HAS_CHILDREN{ return 1; }
@@ -34,7 +35,16 @@ Mail::AuthenticationResults::Header::SubEntry - Class modelling Sub Entry parts
 
 =head1 VERSION
 
-version 1.20180113
+version 1.20180211
+
+=head1 DESCRIPTION
+
+A sub entry is a result which relates to a main entry class, for example if the
+main entry is "dkim=pass" then the sub entry may be "domain.d=example.com"
+
+There may be comments associated with the subentry as children.
+
+Please see L<Mail::AuthenticationResults::Header::Base>
 
 =head1 AUTHOR
 
