@@ -4,12 +4,13 @@ package Mail::AuthenticationResults::Header::Version;
 require 5.010;
 use strict;
 use warnings;
-our $VERSION = '1.20180113'; # VERSION
+our $VERSION = '1.20180211'; # VERSION
 use Scalar::Util qw{ weaken };
 use Carp;
 
 use base 'Mail::AuthenticationResults::Header::Base';
 
+
 sub _HAS_VALUE{ return 1; }
 
 sub as_string {
@@ -67,7 +68,13 @@ Mail::AuthenticationResults::Header::Version - Class modelling the AuthServID pa
 
 =head1 VERSION
 
-version 1.20180113
+version 1.20180211
+
+=head1 DESCRIPTION
+
+A version string, this may be associated with an AuthServID, Entry, Group, or SubEntry.
+
+Please see L<Mail::AuthenticationResults::Header::Base>
 
 =head1 AUTHOR
 
