@@ -4,11 +4,12 @@ package Mail::AuthenticationResults::Token::Separator;
 require 5.010;
 use strict;
 use warnings;
-our $VERSION = '1.20180113'; # VERSION
+our $VERSION = '1.20180211'; # VERSION
 use Carp;
 
 use base 'Mail::AuthenticationResults::Token';
 
+
 sub is {
     my ( $self ) = @_;
     return 'separator';
@@ -45,7 +46,11 @@ Mail::AuthenticationResults::Token::Separator - Class for modelling Authenticati
 
 =head1 VERSION
 
-version 1.20180113
+version 1.20180211
+
+=head1 DESCRIPTION
+
+Token representing a separator
 
 =head1 AUTHOR
 
