@@ -4,11 +4,12 @@ package Mail::AuthenticationResults::Token::String;
 require 5.010;
 use strict;
 use warnings;
-our $VERSION = '1.20180113'; # VERSION
+our $VERSION = '1.20180211'; # VERSION
 use Carp;
 
 use base 'Mail::AuthenticationResults::Token';
 
+
 sub is {
     my ( $self ) = @_;
     return 'string';
@@ -73,7 +74,11 @@ Mail::AuthenticationResults::Token::String - Class for modelling AuthenticationR
 
 =head1 VERSION
 
-version 1.20180113
+version 1.20180211
+
+=head1 DESCRIPTION
+
+Token representing a string
 
 =head1 AUTHOR
 
